@@ -2,7 +2,7 @@
  *   SPDX-FileCopyrightText: 2021 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
  *   SPDX-FileCopyrightText: 2018 Drew DeVault <sir@cmpwn.com>
  *
- *   SPDX-License-Identifier: LGPL-3.0-or-later
+ *   SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #include "interfaces/window.h"
@@ -71,9 +71,6 @@ QWaylandLayerSurface::QWaylandLayerSurface(QWaylandLayerShellIntegration *shell,
 
 QWaylandLayerSurface::~QWaylandLayerSurface()
 {
-    if (m_waitForSyncCallback) {
-        wl_callback_destroy(m_waitForSyncCallback);
-    }
     destroy();
 }
 
@@ -173,7 +170,6 @@ void QWaylandLayerSurface::setWindowGeometry(const QRect &geometry)
     }
 
     setDesiredSize(geometry.size());
-    requestWaylandSync();
 }
 
 bool QWaylandLayerSurface::requestActivate()
@@ -188,14 +184,12 @@ bool QWaylandLayerSurface::requestActivate()
         return true;
     } else {
         const auto focusWindow = QGuiApplication::focusWindow();
-        const auto wlWindow = focusWindow ? static_cast<QtWaylandClient::QWaylandWindow*>(focusWindow->handle()) : window();
+        const auto wlWindow = focusWindow ? static_cast<QtWaylandClient::QWaylandWindow *>(focusWindow->handle()) : window();
         if (const auto seat = wlWindow->display()->lastInputDevice()) {
-            const auto tokenProvider = activation->requestXdgActivationToken(
-                wlWindow->display(), wlWindow->wlSurface(), 0, QString());
-            connect(tokenProvider, &QWaylandXdgActivationTokenV1::done, this,
-                    [this](const QString &token) {
-                        m_shell->activation()->activate(token, window()->wlSurface());
-                    });
+            const auto tokenProvider = activation->requestXdgActivationToken(wlWindow->display(), wlWindow->wlSurface(), 0, QString());
+            connect(tokenProvider, &QWaylandXdgActivationTokenV1::done, this, [this](const QString &token) {
+                m_shell->activation()->activate(token, window()->wlSurface());
+            });
             connect(tokenProvider, &QWaylandXdgActivationTokenV1::done, tokenProvider, &QObject::deleteLater);
             return true;
         }
@@ -214,44 +208,14 @@ void QWaylandLayerSurface::requestXdgActivationToken(quint32 serial)
     if (!activation->isActive()) {
         return;
     }
-    auto tokenProvider = activation->requestXdgActivationToken(
-        window()->display(), window()->wlSurface(), serial, QString());
+    auto tokenProvider = activation->requestXdgActivationToken(window()->display(), window()->wlSurface(), serial, QString());
 
-    connect(tokenProvider, &QWaylandXdgActivationTokenV1::done, this,
-            [this](const QString &token) {
-                Q_EMIT window()->xdgActivationTokenCreated(token);
-            });
+    connect(tokenProvider, &QWaylandXdgActivationTokenV1::done, this, [this](const QString &token) {
+        Q_EMIT window()->xdgActivationTokenCreated(token);
+    });
     connect(tokenProvider, &QWaylandXdgActivationTokenV1::done, tokenProvider, &QObject::deleteLater);
 }
 
-const wl_callback_listener QWaylandLayerSurface::syncCallbackListener = {
-    .done = [](void *data, struct wl_callback *callback, uint32_t time){
-        Q_UNUSED(time);
-        wl_callback_destroy(callback);
-        QWaylandLayerSurface *layerSurface = static_cast<QWaylandLayerSurface *>(data);
-        layerSurface->m_waitForSyncCallback = nullptr;
-        layerSurface->sendExpose();
-    }
-};
-
-void QWaylandLayerSurface::requestWaylandSync()
-{
-    if (m_waitForSyncCallback) {
-        return;
-    }
-
-    m_waitForSyncCallback = wl_display_sync(m_window->display()->wl_display());
-    wl_callback_add_listener(m_waitForSyncCallback, &syncCallbackListener, this);
-}
-
-void QWaylandLayerSurface::handleWaylandSyncDone()
-{
-    if (!window()->isExposed()) {
-        return;
-    }
-    sendExpose();
-}
-
 void QWaylandLayerSurface::sendExpose()
 {
 #if QT_VERSION < QT_VERSION_CHECK(6, 7, 0)
@@ -262,4 +226,3 @@ void QWaylandLayerSurface::sendExpose()
 }
 
 }
-
